#' @export
runCycloneExplorer <- function() {
  appDir <- system.file("shiny", "cyclone-explorer", package = "HIPWITSOTriggers")
  if (appDir == "") {
    stop("Could not find shiny directory. Try re-installing `HIPWITSOTriggers`.", call. = FALSE)
  }

  # Checking for the required datasets
  required_vars <- list(
    id_season_name = "tibble of `usa_atcfid`, and `id` used to select the storm",
    cyclone_points = "`sf` of cyclone points to plot",
    hu_triggers_geo = "`sf` tibble of the hurricane triggers",
    hu_hulls = "`sf` tibble of the 64 knot wind radii corridors",
    ts_triggers_geo = "`sf` tibble of the tropical storm triggers",
    ts_hulls = "`sf` tibble of the 34 knot wind radii corridors",
    rainfall = '`sf` tibble of the four day rainfall amounts'
    )
  for (var in names(required_vars)){
    if (!exists(var)){
      print(glue::glue("Var {var} must exists! {required_vars[[var]]}"))
    }
    if (grepl("trigger", var) && exists(var)) {
      check_columns(get(var), "usa_atcfid", "trigger_type")
      checkmate::check_class(get(var), "sf")
    }
    if (exists(var) && var != "id_season_name") {
      checkmate::check_class(get(var), "sf")
    }
    if (exists(var) && var == "cyclone_points") {
      check_columns(get(var), "usa_atcfid", "lat", "lon", "usa_wind", "r_64","r_34")
    }
  }

  shiny::runApp(appDir, display.mode = "normal")
}