## https://ftp.cpc.ncep.noaa.gov/precip/CPC_UNI_PRCP/GAUGE_CONUS/DOCU/PRCP_CU_GAUGE_V1.0CONUS_0.25deg.README

geodetic_crs <- "EPSG:4326"
delta <- 0.25

# Building the center points
center_points <- grid_center_points(
  grid_size = delta,
  bbox = c(
    "ymin" = 20.125, "ymax" = 49.875,
    "xmin" = -129.875, "xmax" = -55.125
  ),
  crs = geodetic_crs
)

# Building a bounding box around the center points, then creating a grid
bbox <- sf::st_bbox(center_points$geometry) + delta / 2 * c(-1, -1, 1, 1)

grid <- sf::st_make_grid(bbox, cellsize = c(delta, delta)) %>%
  sf::st_as_sf(crs = sf::st_crs(geodetic_crs)) %>%
  dplyr::rename(geometry = x) %>%
  dplyr::mutate(centroid = sf::st_centroid(geometry))

# Pulling in the center points - does the grid cell contain the center point?
grid <- sf::st_join(grid, center_points, join = sf::st_contains)

# Setting the crs, and then transforming to crs of county polygons
rainfall_grid <- grid %>%
  sf::st_transform(crs = sf::st_crs(geodetic_crs))
usethis::use_data(rainfall_grid, overwrite = TRUE)
