% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geo.R
\name{distance_weight}
\alias{distance_weight}
\title{Calculates the inverse distance weight of a tibble}
\usage{
distance_weight(x, col, p = -1, n = 1, adj_list = NULL, by = NULL, dist = NULL)
}
\arguments{
\item{x}{input tibble. Must contain column provided in \code{col} and \code{geoid}}

\item{col}{<\code{\link[=dplyr_tidy_select]{tidy-select}}> of single column}

\item{p}{the distance weight (p = -1 for inverse distance)}

\item{n}{reserved}

\item{adj_list}{county adjacency list. Must have columns geoid and adj_geoid,
describing the county and it's adjacent neighbors}

\item{by}{vector of names to join by (keys) if geoid does not uniquely describe
the tibble}

\item{dist}{tibble of \code{geoid}, \code{adj_geoid} , and \code{distance}. If not
provided then the distance is determined from the supplied geometry.
Supplying the distance allows for caching the expensive distance results.}
}
\description{
Determines the inverse distance weight of a column in a tibble. The weight
is calculated as:
\enumerate{
\item Joining each of the geoid to it's neighbors and adding the value
\item Determining the distance of the geoid to its neighbors
\item Computing the weighted mean ( sum( dist ^ p * val) / sum(dist ^ p))
}
}
\details{
When computing the weighted mean the identity (geoid == adj_geoid) is
removed.
}
\note{
If supplied a distance, shouldn't need to
}
