# Builds example storms

library(tidyverse)
library(sf)
library(lubridate)

build_sample_a <- function() {
  crs <- "EPSG:5070"
  wind <- c(60, 65, 65, 60)
  radii <- c(NA_real_, 10, 10, NA_real_)
  times <- seq(lubridate::as_datetime("2020-01-01"), by = "3 hours", length.out = length(wind))
  lon <- 0
  lat <- seq(from = 30, by = 1, length.out = length(wind))
  data <- tibble::tibble(
    usa_atcfid = "a",
    iso_time = times,
    usa_wind = wind,
    R = radii,
    lon = lon,
    lat = lat
  ) %>%
    sf::st_as_sf(
      coords = c("lon", "lat"), crs = crs
    )

  return(data)
}

build_sample_b <- function() {
  crs <- "EPSG:5070"
  wind <- c(60, 65, 65, 60)
  radii <- c(NA_real_, 10, 10, NA_real_)
  times <- seq(lubridate::as_datetime("2020-01-01"), by = "3 hours", length.out = length(wind))
  lon <- seq(from = 20, by = 1, length.out = length(wind))
  lat <- seq(from = 30, by = 1, length.out = length(wind))
  data <- tibble::tibble(
    usa_atcfid = "b",
    iso_time = times,
    usa_wind = wind,
    R = radii,
    lon = lon,
    lat = lat
  ) %>%
    sf::st_as_sf(
      coords = c("lon", "lat"), crs = crs
    )

  return(data)
}

build_sample_c <- function() {
  crs <- "EPSG:5070"
  wind <- c(60, 65, 65, 60, 65, 64, 60, 75, 60)
  radii <- c(NA_real_, 10, 10, NA_real_, 5, 5, NA_real_, 10, NA_real_)
  times <- seq(lubridate::as_datetime("2020-01-01"), by = "3 hours", length.out = length(wind))
  lon <- c(rep(20, 4), seq(from = 20, by = 1, length.out = length(wind) - 5))
  lon <- c(lon, max(lon) + 2)
  lat <- seq(from = 30, by = 1, length.out = length(wind))
  data <- tibble::tibble(
    usa_atcfid = "c",
    iso_time = times,
    usa_wind = wind,
    R = radii,
    lon = lon,
    lat = lat
  ) %>%
    sf::st_as_sf(
      coords = c("lon", "lat"), crs = crs
    )

  return(data)
}

build_sample_e <- function() {
  crs <- "EPSG:5070"
  wind <- c(60, 65, 60)
  radii <- c(NA_real_, 10, NA_real_)
  times <- seq(lubridate::as_datetime("2020-01-01"), by = "3 hours", length.out = length(wind))
  lon <- 0
  lat <- seq(from = 30, by = 1, length.out = length(wind))
  data <- tibble::tibble(
    usa_atcfid = "a",
    iso_time = times,
    usa_wind = wind,
    R = radii,
    lon = lon,
    lat = lat
  ) %>%
    sf::st_as_sf(
      coords = c("lon", "lat"), crs = crs
    )

  return(data)
}

build_sample_hdp <- function() {
  crs <- "EPSG:4326"
  lat <- c(
    21.3000, 21.6999, 22.1000, 22.5072, 22.9000, 23.2574, 23.6000, 23.9649, 24.3000, 24.5650)
  lon <- c(
    -74.0000, -74.5877, -75.1000, -75.5228, -75.9000, -76.3003, -76.7000, -77.1001, -77.5000, -77.9152)
  usa_wind <- c(60, 65, 70, 75, 80, 90, 80, 75, 70, 60)
  R <- c(NA_real_, 15, 25, 30, 35, 35, 30, 20, 10, NA_real_)

  times <- seq(from = lubridate::as_datetime("2020-09-20"), by = "3 hours", length.out = length(usa_wind))

  dplyr::tibble(
    usa_atcfid = "HDP",
    iso_time = times,
    usa_wind = usa_wind,
    R = R,
    lon = lon,
    lat = lat
  ) %>%
    sf::st_as_sf(
      coords = c("lon", "lat"), crs = crs
    )
}

build_ian <- function() {
  crs <- "EPSG:4326"
  ian <- readr::read_csv(fs::path(testthat::test_path(), "fixtures", "ian.csv"),
                         col_types = readr::cols(
                           usa_atcfid = col_character(),
                           name = col_character(),
                           iso_time = col_datetime(format = ""),
                           usa_wind = col_double(),
                           r_64 = col_double(),
                           lon = col_double(),
                           lat = col_double()
                         ))
  # converting to an sf
  ian %>%
    sf::st_as_sf(
      coords = c("lon", "lat"), crs = crs
    )
}
