# Getting Geo - Cleaned up after run
if (require("tigris", quietly = T)){
  rlang::inform("Getting the geometry and building the adjacency list for testing")
  raw_geo <- tigris::counties()
  adj_geo <- raw_geo  %>%
    dplyr::filter(!(STATEFP %in% c("78", "66", "69", "60", "15"))) %>%
    janitor::clean_names()
  adj <- calc_adjacency(adj_geo, self_adj = TRUE)
}

test_that("Grid Geo Check", {
  grid <- grid_center_points(grid_size = 0.25,
                             bbox = c("ymin"=20.125, "ymax"=49.875, "xmin"=-129.875, "xmax"=-55.125),
                             crs = "EPSG:4326")
  expect_equal(nrow(grid), 300*120)
  expect_s3_class(grid, "sf")
})

test_that("Distance Check", {

  skip_if_not_installed("tigris")
  skip_if_not(exists("raw_geo"), "Geometry not created")
  geo <- raw_geo %>%
    dplyr::filter(!(STATEFP %in% c("78", "66", "69", "60", "15")))

  # Expect to get data back
  expect_warning(
    dist <- calc_distance_geo(geo)
  )

  # Do we have neighbors?
  expect_setequal(dist$geoid, dist$adj_geoid)
  # Do we cover all GEOIDS
  expect_setequal(dist$geoid, geo$GEOID)

  # Reflexive check - Lehigh County To Florida
  result <- dist %>%
    dplyr::filter((geoid == "12003" & adj_geoid == "42077") |
    (geoid == "42077" & adj_geoid == "12003") )
  expect_equal(result$distance[1], result$distance[2])
  expect_equal(units::drop_units(result$distance[1]), 1292918, tolerance = 0.01)
})


test_that("Adjacency Check", {
  skip_if_not_installed("tigris")
  skip_if_not(exists("adj"), "Adjacency not created")

  # Confirmation of self
  self_adj <- adj %>%
    dplyr::filter(geoid == adj_geoid)
  expect_setequal(self_adj$geoid, adj_geo$geoid)
})

test_that("Distance Weighting Check", {
  skip_if_not_installed("tigris")
  skip_if_not(exists("adj"), "Adjacency not created")
  skip_if_not(FALSE, "test not implemented")

})
