test_that("hull: sample a", {
  # Dummy Data
  data <- build_sample_a() %>%
    dplyr::mutate(R = R * 0.1)

  result <- build_hulls(data, r = R, grp_vars = usa_atcfid, usa_wind >= 64, .summarize = FALSE, .parallel = FALSE)

  if (FALSE) {
    ggplot() +
      geom_sf(data = result, aes(geometry = geometry)) +
      geom_sf(data = data, aes(geometry = geometry),size = 2)
  }

  # Checking that the class is correct, with 2 entry
  expect_s3_class(result, "sf")
  expect_equal(nrow(result), 2)

  # Summarize should only return one
  result_2 <- build_hulls(data, r = R, grp_vars = usa_atcfid, usa_wind >= 64, .summarize = TRUE, .parallel = FALSE)
  expect_equal(nrow(result_2), 1)

  # Areas should match
  expect_equal(sf::st_area(sf::st_union(result)), sf::st_area(result_2))
})

test_that("Bad Hulls - All NaN provided", {
  data <- build_sample_a() %>%
    dplyr::mutate(R = NA_real_)

  expect_warning(
    result <- build_hulls(data, r = R, grp_vars = usa_atcfid, usa_wind >= 64, .summarize = FALSE, .parallel = FALSE)
  )
  expect_s3_class(result, "sf")

})

test_that("Bad Hulls - One storm has NaN provided", {
  data <- dplyr::bind_rows(
    build_sample_a() %>%
      dplyr::mutate(R = NA_real_),
    build_sample_c())

  expect_warning(
    result <- build_hulls(data, r = R, grp_vars = usa_atcfid, usa_wind >= 64, .summarize = FALSE, .parallel = FALSE)
  )
  expect_s3_class(result, "sf")

})

test_that("Cyclone with a single HU point: sample e", {

  sample <- build_sample_e()

  expect_warning({
    hull <- sample %>%
      build_hulls(R, grp_vars = c(usa_atcfid), usa_wind >= 64,
                  .parallel = FALSE)
  })

  expect_equal(nrow(hull), 1)
})

test_that("hull: sample c - disjoint", {
  # Dummy Data
  data <- build_sample_c() %>%
    dplyr::mutate(R = R * 0.1)

  expect_warning(
    result <- build_hulls(data, r = R, grp_vars = usa_atcfid, usa_wind >= 64, .summarize = TRUE, .parallel = FALSE)
  )

  if (FALSE) {
    ggplot() +
      geom_sf(data = result, aes(geometry = geometry)) +
      geom_sf(data = data, aes(geometry = geometry),size = 2)
  }

  # Checking that the class is correct, with 1 entry
  expect_s3_class(result, "sf")
  expect_equal(nrow(result), 3)

})

test_that("hull: point - HDP", {
  # Dummy Data
  data <- readRDS(test_path("fixtures", "hdp.rds")) %>%
    dplyr::mutate(R = R * 1852) # Nautical Miles to meters

  result <- build_hulls(data, r = R, grp_vars = c(usa_status), usa_status == "HU", .summarize = TRUE, .parallel = FALSE)

  # Checking that the class is correct, with 1 entry
  expect_s3_class(result, "sf")
  expect_equal(nrow(result), 1)

})

test_that("hull: point - HDP - parallel and serial", {
  # Dummy Data
  data <- readRDS(test_path("fixtures", "hdp.rds")) %>%
    dplyr::mutate(R = R * 1852) # Nautical Miles to meters

  result_serial <- build_hulls(data, r = R, grp_vars = c(usa_status), usa_status == "HU", .summarize = TRUE, .parallel = FALSE)
  result_parallel <- build_hulls(data, r = R, grp_vars = c(usa_status), usa_status == "HU", .summarize = TRUE, .parallel = TRUE)

  # Checking that the class is correct, with 1 entry
  expect_s3_class(result_serial, "sf")
  expect_s3_class(result_parallel, "sf")
  expect_equal(nrow(result_serial), 1)
  expect_equal(sf::st_drop_geometry(result_serial), sf::st_drop_geometry(result_parallel))

})
