test_that("shapefile_download IBTrACS - no cache", {
  skip_if_offline(host = "www.ncei.noaa.gov")
  url <- getOption("hipwits_ibtracs_endpoint") # ~ 6 MB

  f <- load_shapefile(url, progress = FALSE)
  expect_s3_class(f, c("sf", "data.frame"))
})

test_that("shapefile_download US Census - no cache", {
  skip_if_offline(host = "www.census.gov" )
  url <- "https://www2.census.gov/geo/tiger/TIGER2022/COUNTY/tl_2022_us_county.zip" # ~80 MB
  url <- "http://www2.census.gov/geo/tiger/GENZ2020/shp/cb_2020_us_county_20m.zip" # ~ 1 M
  f <- load_shapefile(url, progress = FALSE)
  expect_s3_class(f, c("sf", "data.frame"))
})


test_that("hipwits_use_cache setup: user supplied directory", {
  dir <- tempdir()

  cache_dir <- local_create_cache(dir = dir)

  expect_true(fs::dir_exists(cache_dir))
  expect_equal(cache_dir, dir)
  expect_equal(Sys.getenv("HIPWITS_CACHE_DIR"), cache_dir)
  expect_equal(getOption("hipwits_use_cache"), TRUE)
})

test_that("hipwits_use_cache setup: default directory", {
  # Skipping if the user already has an entry in the $HOME\.Re
  renv <- fs::path(Sys.getenv("HOME"), ".Renviron")
  skip_if(
    condition = fs::file_exists(renv) &&
      isTRUE(any(grepl("HIPWITS_CACHE_DIR", readLines(renv)))),
    message = "User arealdy has an entry in .Renviron for HIPWITS_CACHE_DIR"
  )

  # Doing the test
  cache_dir <- local_create_cache(dir = NULL)

  expect_true(fs::dir_exists(cache_dir))
  expect_equal(Sys.getenv("HIPWITS_CACHE_DIR"), "")
  expect_equal(getOption("hipwits_use_cache"), TRUE)
})

test_that("hipwits_use_cache setup: user supplied directory", {
  dir <- tempdir()

  cache_dir <- local_create_cache(dir = dir)

  expect_true(fs::dir_exists(cache_dir))
  expect_equal(cache_dir, dir)
  expect_equal(Sys.getenv("HIPWITS_CACHE_DIR"), cache_dir)
  expect_equal(getOption("hipwits_use_cache"), TRUE)
})

test_that("shapefile_download cache", {
  # Setting up the local cache
  dir <- tempdir()
  cache_dir <- local_create_cache(dir = dir)

  # Small and quick
  url <- "http://www2.census.gov/geo/tiger/GENZ2020/shp/cb_2020_us_county_20m.zip"

  f <- load_shapefile(url, progress = FALSE, keep_zipped_shapefile = TRUE)
  expect_s3_class(f, c("sf", "data.frame"))

  # Expect to see it in the cache_dir
  expect_true(fs::file_exists(fs::path(cache_dir, basename(url))))
})

test_that("load_lnx - single url", {
  # Setting up the local cache
  dir <- tempdir()
  cache_dir <- local_create_cache(dir = dir)

  # Small and quick
  url <- fs::path(getOption("hipwits_gauge_conus_daily_endpoint"),"RT","2023","PRCP_CU_GAUGE_V1.0CONUS_0.25deg.lnx.20230101.RT")

  obj <- load_lnx(url, progress = FALSE)

  # Expect to see it in the cache_dir
  expect_true(fs::file_exists(fs::path(cache_dir, basename(url))))
  expect_s3_class(obj, "tbl")
})

test_that("load_lnx - date range", {
  # Setting up the local cache
  dir <- tempdir()
  cache_dir <- local_create_cache(dir = dir)

  # Small and quick
 int_1 <- lubridate::interval("2018-12-30T12:00:00Z/2019-01-02T12:00:00Z")

  obj <- load_lnx(int_1, progress = FALSE)

  # Expect to see it in the cache_dir
  expect_s3_class(obj, "tbl")
  expect_equal(length(unique(obj$date)), 4)
})

test_that("load_lnx - multiple dates", {
  # Setting up the local cache
  dir <- tempdir()
  cache_dir <- local_create_cache(dir = dir)

  # Small and quick
 keys <- c("20230101","20230102")

  obj <- load_lnx(keys, progress = FALSE)

  # Expect to see it in the cache_dir
  expect_s3_class(obj, "tbl")
  expect_equal(length(unique(obj$date)), 2)
})
