test_that("NOAA CPC GAUGE CONUS Range Query", {

  int_1 <- lubridate::interval("2018-12-30T12:00:00Z/2019-01-02T12:00:00Z")
  results_f <- get_gauge_conus_datasets(int_1, use_updated = FALSE)
  results_t <- get_gauge_conus_datasets(int_1, use_updated = TRUE)

  expect_equal(length(results_f), 4) # 30, 31, 1, 2nd
  expect_equal(length(results_f), length(results_t))

})

test_that("NOAA CPC GAUGE CONUS Single Date", {
  results_f <- get_gauge_conus_datasets("20131029")
  expect_equal(length(results_f), 1)

  results_f1 <- get_gauge_conus_datasets(lubridate::as_datetime("20131029"))
  expect_equal(length(results_f1), 1)
  expect_equal(results_f, results_f1)

})

test_that("NOAA CPC GAUGE CONUS URL", {
  url <- fs::path(getOption("hipwits_gauge_conus_daily_endpoint"),"RT","2023","PRCP_CU_GAUGE_V1.0CONUS_0.25deg.lnx.20230101.RT")

  results_f <- get_gauge_conus_datasets(url)
  expect_equal(length(results_f), 1)
  expect_equal(results_f, url)

})

test_that("NOAA CPC GAUGE CONUS Single Date", {
  fname <- get_gauge_conus_datasets("20131029")

  grid <- grid_center_points()
  p <- read_lnx(fname, grid)

  # Zapata County TX - all zeros
  idx <- c(7924,7925,8223,8224,8225,8523,8524,8525,8823,8824,8825)
  zapata <- p %>%
    dplyr::filter(GRIDID %in% idx)
  expect_equal(sum(zapata$rainfall), units::as_units("0 mm"))
})


test_that("read_lnx_raw", {

  url <- "https://ftp.cpc.ncep.noaa.gov/precip/CPC_UNI_PRCP/GAUGE_CONUS/RT/2023/PRCP_CU_GAUGE_V1.0CONUS_0.25deg.lnx.20230101.RT"
  tmp <- tempfile()
  withr::local_file(tmp)
  download_file(url, tmp,  progress_bar = FALSE, refresh = TRUE)

  # read the file
  data <- read_lnx_raw(tmp)
  expect_vector(data, ptype = numeric(), size = 36000)
})
