# Getting the data for the test (cleaned up once test completed)
if (require("tigris", quietly = T)){
  rlang::inform("Getting the geometry and building the adjacency list for testing")
  geo <- tigris::counties() %>%
    dplyr::rename(geoid = GEOID)
  geo <- geo %>%
    dplyr::filter(!(STATEFP %in% c("78", "66", "69", "60", "15")))
  county_adj <- calc_adjacency(geo, self_adj = TRUE)
}

# Testing that we can build a cyclone with a single point
test_that("Test Adjacent Trigger", {

  skip_if_not_installed("tigris")
  skip_if_not(exists("county_adj"), "County Adjacency not created")

  dummy <- tibble::tribble(
    ~geoid, ~iso_time, ~id,
    "36093", '2016-01-01', "2016_1",
    "36093", '2016-01-01', "2016_2",
    "36093", '2017-01-01', "2017_1",
    "42077", '2020-01-01', "2020_1"
  ) %>%
    dplyr::mutate(iso_time = lubridate::as_datetime(iso_time))

  adj_triggers <- direct_indirect_triggers(dummy, county_adj  = county_adj, id_vars = id)

  n_36093 <- county_adj %>%
    filter(geoid == "36093") %>%
    nrow()

  n_42077 <- county_adj %>%
    filter(geoid == "42077") %>%
    nrow()

  # 42077 has 7 adj (1 year), 36093 has 5 adj (three years)
  expect_equal(nrow(adj_triggers), 3 * n_36093 + 1 * n_42077)
})


test_that("Test Wind Trigger", {

  skip_if_not_installed("tigris")
  skip_if_not(exists("county_adj"), "County Adjacency not created")
  skip_if_not(FALSE, "test not implemented.")
})

test_that("Test Rainfall Trigger", {
  # Building a dummy dataset
  dates <- seq(lubridate::as_date("1862-05-15"), lubridate::as_date("1862-05-30"), by = "1 days")
  data <- tidyr::tibble(
    date = dates,
    rainfall = c(2, rep(1, 5), 0, 0, 0, 0, rep(2, 5), 1)
  ) %>%
    dplyr::mutate(geoid = "12345")

 triggers <- rainfall_trigger(data, threshold = 3, lag_days = 1, lead_days = 2, default = 0)

  # Hand check
  expect_equal(nrow(triggers), 12)
  expect_equal(triggers$cum_sum, c(4, 5, 4, 4, 3, 4, 6, 8, 8, 7, 5, 3))
})
